"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sdk_1 = require("@wormhole-foundation/sdk");
const evm_1 = __importDefault(require("@wormhole-foundation/sdk/evm"));
const solana_1 = __importDefault(require("@wormhole-foundation/sdk/solana"));
// register protocol implementations
require("@wormhole-foundation/sdk-evm-ntt");
require("@wormhole-foundation/sdk-solana-ntt");
const sdk_route_ntt_1 = require("@wormhole-foundation/sdk-route-ntt");
const consts_js_1 = require("./consts.js");
const helpers_js_1 = require("./helpers.js");
(async function () {
    const wh = await (0, sdk_1.wormhole)("Testnet", [solana_1.default, evm_1.default]);
    const src = wh.getChain("Solana");
    const dst = wh.getChain("ArbitrumSepolia");
    const srcSigner = await (0, helpers_js_1.getSigner)(src);
    const dstSigner = await (0, helpers_js_1.getSigner)(dst);
    const resolver = wh.resolver([
        (0, sdk_route_ntt_1.nttManualRoute)({ tokens: consts_js_1.NttTokens }),
        (0, sdk_route_ntt_1.nttAutomaticRoute)({ tokens: consts_js_1.NttTokens }),
    ]);
    const srcTokens = await resolver.supportedSourceTokens(src);
    console.log("Allowed source tokens: ", srcTokens.map((t) => (0, sdk_1.canonicalAddress)(t)));
    // Just grab the first one
    const sendToken = srcTokens[0];
    // given the send token, what can we possibly get on the destination chain?
    const destTokens = await resolver.supportedDestinationTokens(sendToken, src, dst);
    console.log("For the given source token and routes configured, the following tokens may be receivable: ", destTokens.map((t) => (0, sdk_1.canonicalAddress)(t)));
    //grab the first one for the example
    const destinationToken = destTokens[0];
    // creating a transfer request fetches token details
    // since all routes will need to know about the tokens
    const tr = await sdk_1.routes.RouteTransferRequest.create(wh, {
        from: srcSigner.address,
        to: dstSigner.address,
        source: sendToken,
        destination: destinationToken,
    });
    // resolve the transfer request to a set of routes that can perform it
    const foundRoutes = await resolver.findRoutes(tr);
    console.log("For the transfer parameters, we found these routes: ", foundRoutes);
    // Taking the first route here, they'll be sorted by output amount
    // but you can chose any of them
    const bestRoute = foundRoutes[0];
    console.log("Selected: ", bestRoute);
    // Figure out what options are availiable
    const options = bestRoute.getDefaultOptions();
    console.log("This route offers the following default options", options);
    // Validate the transfer params passed
    // This fetches the next bits of data necessary and parses amounts or other values
    // it returns a new type: `ValidatedTransferParams`.
    // This is a validated version of the input params which must be passed to the next step
    const validated = await bestRoute.validate({ amount: "0.00001", options });
    if (!validated.valid)
        throw validated.error;
    console.log("Validated parameters: ", validated.params);
    // Fetch quote for the transfer
    // this, too, returns a new type that must be passed to the next step (if you like the quote)
    const quote = await bestRoute.quote(validated.params);
    if (!quote.success)
        throw quote.error;
    console.log("Quote for transfer: ", quote);
    // Now the transfer may be initiated
    // A receipt will be returned, guess what you gotta do with that?
    const receipt = await bestRoute.initiate(srcSigner.signer, quote);
    console.log("Initiated transfer with receipt: ", receipt);
    // Kick off a wait log and executor
    // If there is an opportunity to advance it to the next step, it will take it
    // ie complete or finalize
    // see the implementation for how this works
    await sdk_1.routes.checkAndCompleteTransfer(bestRoute, receipt, dstSigner.signer);
})();
//# sourceMappingURL=route.js.map